# k8s-collector

A Helm chart for Secure State Kubernetes collector

## Additional Information

This tool can be used to attach your Kubernetes cluster to CloudHealth Secure State.

By attaching your Kubernetes clusters you can take advantage of real-time monitoring for misconfigurations and security
violations corresponding to CIS Kubernetes Benchmark standards, and build a more complete image of your organization's
security posture in the cloud.

## Installing the Chart

To install the chart with the release name `aria-k8s-collector`:

The available Chart options are listed further down. Refer to this list for required and optional parameters.

### Helm 3.8+

Helm 3.8 adopted a different distribution model for Charts. OCI image registries are the preferred method of
distributing Charts going forward.

```console
$ helm install aria-k8s-collector oci://projects.registry.vmware.com/securestate/helm-charts/k8s-collector
```

### Minimum Chart parameters

Specify the necessary values using the `--set key=value[,key=value] argument` to `helm install`. For example,

```console
$ helm install aria-k8s-collector vmware-securestate/k8s-collector \
    --namespace <YOUR NAMESPACE> \
    --create-namespace \
    --set config.clusterCloudAccountId=<CLOUD ACCOUNT ID>
    --set config.clusterName=<CLUSTER NAME> \
    --set config.clusterRegion=<CLUSTER REGION> \
    --set config.collectorId=<COLLECTOR ID> \
    --set csp.clientId=<CSP CLIENT ID> \
    --set csp.clientSecret=<CSP CLIENT SECRET> \
    --set csp.orgId=<CSP ORGANIZATION ID>
```

Users of `zsh` might need to put quotes around key/value pairs.

## Upgrading

No upgrades are available at this time.

## Uninstall

Note: when you uninstall the Collector, configured clusters will remain untouched in the Secure State UI.

```console
$ helm uninstall <RELEASE NAME> -n <YOUR NAMESPACE>
```

## Troubleshooting the deployment

The following may be useful when troubleshooting your Chart deployments.

The collector will go into a CrashLoopBackoff if there is a problem with its configuration. This is expected
behavior as it ensure that the collector is not running in a misconfigured way, and raises any misconfigurations
directly to the collector operators.

### Collector reports that location is empty

This is likely caused by deploying the Chart on a Kubernetes cluster that you self manage. A self-managed cluster is
one whose control plane is managed by you. These differ from clusters managed by cloud providers.

The chart's default configuration assumes that your cluster is managed by a cloud provider.

If you are managing your own Kubernetes control plane, set the following value to `true`.

```console
config:
  # -- Whether the cluster is self-managed (`true``), or managed by a cloud provider (`false`).
  clusterManaged: false
```

### User is not authorized to access this resource with an explicit deny

If your collector raises this error, it is likely due to an incorrect

* `config.collectorId`
* `csp.clientId`
* `csp.clientSecret`
* `csp.orgId`

Ensure that the value in the first three bullet-points above accurately reflect your collector's configure in Secure
State.

If you specify your credential in the `extraEnvVars` field, ensure that the value that you specify is **not** base64
encoded; `helm` will automatically `base64` encode this value for you, so you should not encode it yourself.

## Requirements

Kubernetes: `>=1.18.0-0`

## Values

| Key | Type | Default | Description |
|-----|------|---------|-------------|
| collector.affinity | string | `"podAntiAffinity:\n  requiredDuringSchedulingIgnoredDuringExecution:\n    - labelSelector:\n        matchLabels:\n          app.kubernetes.io/name: {{ template \"collector.name\" . }}\n          app.kubernetes.io/instance: \"{{ .Release.Name }}\"\n          component: otel-collector\n      topologyKey: kubernetes.io/hostname\n"` |  |
| collector.annotations | object | `{}` |  |
| collector.enabled | string | `"-"` |  |
| collector.extraArgs | list | `[]` |  |
| collector.extraContainers | list | `[]` |  |
| collector.extraEnvironmentVars | object | `{}` |  |
| collector.extraInitContainers | list | `[]` |  |
| collector.extraLabels | object | `{}` |  |
| collector.extraSecretEnvironmentVars | list | `[]` |  |
| collector.extraVolumes | list | `[]` |  |
| collector.image.imagePullSecrets | list | `[]` |  |
| collector.image.pullPolicy | string | `"IfNotPresent"` |  |
| collector.image.repository | string | `"projects.registry.vmware.com/aria/k8s-collector"` |  |
| collector.image.tag | string | `"1.34.2"` |  |
| collector.initContainers | list | `[]` |  |
| collector.labels | object | `{}` |  |
| collector.minReadySeconds | int | `5` |  |
| collector.networkPolicy.egress | list | `[]` |  |
| collector.networkPolicy.enabled | bool | `false` |  |
| collector.nodeSelector | object | `{}` |  |
| collector.postStart | list | `[]` |  |
| collector.preStop | list | `[]` |  |
| collector.priorityClassName | string | `""` |  |
| collector.progressDeadlineSeconds | int | `120` |  |
| collector.replicas | int | `1` |  |
| collector.resources.limits.cpu | string | `"1000m"` |  |
| collector.resources.limits.memory | string | `"1Gi"` |  |
| collector.resources.requests.cpu | string | `"100m"` |  |
| collector.resources.requests.memory | string | `"64Mi"` |  |
| collector.securityContext.container | object | `{}` |  |
| collector.securityContext.pod | object | `{}` |  |
| collector.serviceAccount.annotations | object | `{}` |  |
| collector.serviceAccount.create | bool | `true` |  |
| collector.serviceAccount.extraLabels | object | `{}` |  |
| collector.serviceAccount.name | string | `""` |  |
| collector.shareProcessNamespace | bool | `false` |  |
| collector.terminationGracePeriodSeconds | int | `10` |  |
| collector.tolerations | list | `[]` |  |
| collector.topologySpreadConstraints | list | `[]` |  |
| collector.updateStrategyType | string | `"Recreate"` |  |
| collector.volumeMounts | list | `[]` |  |
| collector.volumes | list | `[]` |  |
| config.clusterCloudAccountId | string | `""` |  |
| config.clusterCloudProvider | string | `"AWS"` |  |
| config.clusterManaged | bool | `false` |  |
| config.clusterName | string | `""` |  |
| config.clusterRegion | string | `"NA"` |  |
| config.collectorId | string | `""` |  |
| config.enableLogging | bool | `false` |  |
| config.environment | string | `"prod"` |  |
| csp.clientId | string | `""` |  |
| csp.host | string | `"https://console.cloud.vmware.com"` |  |
| csp.orgId | string | `""` |  |
| global.enabled | bool | `true` |  |
| global.imagePullSecrets | list | `[]` |  |
| metrics.enabled | bool | `true` |  |
| metrics.podAnnotations."prometheus.io/path" | string | `"/metrics"` |  |
| metrics.podAnnotations."prometheus.io/port" | string | `"8080"` |  |
| metrics.podAnnotations."prometheus.io/scrape" | string | `"true"` |  |
| metrics.service.annotations | object | `{}` |  |
| metrics.service.labels | object | `{}` |  |
| tap_observability_config.http_ingestion_url | string | `""` |  |
| tap_observability_config.lemans_access_key | string | `""` |  |
| tap_observability_config.metrics_domain | string | `""` |  |
| tap_observability_config.metrics_storage_policy | string | `""` |  |